@@ -3,6 +3,7 @@ import threading
 import multiprocessing
 import random
 import string
+import os
 
 def generate_random_string(length): # 生成随机序列号，用于全局标定一个任务
     characters = string.ascii_letters + string.digits
@@ -14,6 +15,31 @@ def generate_random_string(length): # 生成随机序列号，用于全局标定
 #   RUN : 正在运行
 #   TERM: 运行已经结束（可能是出错或者正常结束）
 
+def savedata(filepath: str, data: str): # 将数据存储到指定文件
+    dirpos = os.path.dirname(os.path.abspath(filepath))
+    os.makedirs(dirpos, exist_ok=True) # 保证文件存在
+    try:
+        fp = open(filepath, "w")
+        fp.write(data)
+    except:
+        pass
+
+def getdata(filepath: str) -> str: # 读取数据并删除文件
+    dirpos = os.path.dirname(os.path.abspath(filepath))
+    os.makedirs(dirpos, exist_ok=True) # 保证文件存在
+    ans = ""
+    try:
+        fp = open(filepath, "r")
+        ans = fp.read()
+    except:
+        pass
+    finally: # 删除临时文件
+        try:
+            os.remove(filepath)
+        except:
+            pass
+    return ans
+
 global_inner_process_wrap_dict = {}
 
 class InnerProcessWrap:
@@ -42,7 +68,6 @@ class InnerProcessWrap:
         self.return_value    = None
         self.end_flag        = False # 是否进行过死亡结算
         self.aux_info        = {}
-        self.queue           = None
         self.lock            = threading.Lock()
 
     # 获取当前状态所处的时间
@@ -74,11 +99,13 @@ class InnerProcessWrap:
                     self.run_time     = time.time() - self.begin_time # 总运行时间
                     self.begin_time   = time.time()
                     try:
-                        self.return_value = self.queue.get_nowait() # 不要等待
+                        self.pobj.join() # 结束进程
+                    except:
+                        pass
+                    try:
+                        self.return_value = getdata("/tmp/%s" % self.obj_uuid)
                     except:
                         self.return_value = None
-                    finally:
-                        self.queue = None
                 update_dic = { # 程序已经运行结束
                     "status": "TERM",
                     "info": {
@@ -93,12 +120,11 @@ class InnerProcessWrap:
     def run_task(self):
         if self.pobj is not None: # 不要重复启动已经启动过的任务
             return
-        def worker(queue, args: list) -> None:
+        def worker(args: list) -> None:
             tmp = self.worker_function(*args)
-            queue.put(tmp)
-        self.queue = multiprocessing.Queue()
+            savedata("/tmp/%s" % self.obj_uuid, str(tmp))
         self.begin_time = time.time()
-        self.pobj       = multiprocessing.Process(target=worker, args=(self.queue, self.args, ))
+        self.pobj       = multiprocessing.Process(target=worker, args=(self.args, ))
         self.pobj.start()
         self.monitor.start() # 启动监视器线程
 
@@ -117,7 +143,7 @@ class InnerProcessWrap:
 
 def test1():
     def test_function(a, b, c, d) -> str:
-        time.sleep(1)
+        time.sleep(3)
         return "%d, %d, %d, %d" % (a, b, c, d)
     pw = InnerProcessWrap(test_function, (1, 2, 3, 4))
     print(pw.get_status())
